# remirepo/fedora spec file for php-tecnickcom-tc-lib-unicode
#
# SPDX-FileCopyrightText:  Copyright 2016-2025 Remi Collet
# SPDX-License-Identifier: CECILL-2.1
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# Please, preserve the changelog entries
#
%global gh_commit    48f04cfa8c9843722bb263f80082ca888cbcdf58
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global c_vendor     tecnickcom
%global gh_owner     tecnickcom
%global gh_project   tc-lib-unicode
%global php_project  %{_datadir}/php/Com/Tecnick/Unicode
%global with_tests   0%{!?_without_tests:1}

Name:           php-%{gh_owner}-%{gh_project}
Version:        2.0.20
Release:        1%{?dist}
Summary:        PHP library containing Unicode methods

License:        LGPL-3.0-or-later
URL:            https://github.com/%{gh_owner}/%{gh_project}
Source0:        https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{name}-%{version}-%{?gh_short}.tar.gz

BuildArch:      noarch
%if %{with_tests}
# For tests
%global phpunit %{_bindir}/phpunit10
BuildRequires:  phpunit10 >= 10.5.40
BuildRequires:  php(language) >= 8.1
BuildRequires: (php-composer(%{c_vendor}/tc-lib-unicode-data) >= 2.0    with php-composer(%{c_vendor}/tc-lib-unicode-data) < 3)
BuildRequires:  php-mbstring
BuildRequires:  php-pcre
%endif
BuildRequires:  php-fedora-autoloader-devel

# From composer.json, "require": {
#        "php": ">=8.1"
#        "ext-mbstring": "*",
#        "ext-pcre": "*",
#        "tecnickcom/tc-lib-unicode-data": "^2.0"
Requires:       php(language) >= 8.1
Requires:       php-mbstring
Requires:       php-pcre
Requires:      (php-composer(%{c_vendor}/tc-lib-unicode-data) >= 2.0    with php-composer(%{c_vendor}/tc-lib-unicode-data) < 3)
# From phpcompatinfo report for version 1.2.1
# None
BuildRequires:  php-fedora-autoloader-devel

# Composer
Provides:       php-composer(%{c_vendor}/%{gh_project}) = %{version}
# Upstream package name
Provides:       php-%{gh_project} = %{version}


%description
PHP library containing Unicode and UTF-8 methods, including the
Unicode Bidirectional Algorithm.

The initial source code has been derived from TCPDF (http://www.tcpdf.org/).


%prep
%setup -q -n %{gh_project}-%{gh_commit}

: Sanity check
grep -q '^%{version}$' VERSION


%build
phpab --template fedora --output src/autoload.php src
cat << 'EOF' | tee -a src/autoload.php
\Fedora\Autoloader\Dependencies::required([
    '%{_datadir}/php/Com/Tecnick/Unicode/Data/autoload.php',
]);
EOF


%install
mkdir -p   $(dirname %{buildroot}%{php_project})
cp -pr src %{buildroot}%{php_project}


%check
%if %{with_tests}
mkdir vendor
cat << 'EOF' | tee vendor/autoload.php
<?php
require '%{buildroot}%{php_project}/autoload.php';
\Fedora\Autoloader\Autoload::addPsr4('Test\\', dirname(__DIR__) . '/test');
EOF

ret=0
for cmdarg in php php81 php82 php83 php84; do
   if which $cmdarg; then
      set $cmdarg
      cp phpunit.xml.dist phpunit.xml
      $1 ${2:-%{phpunit}} --migrate-configuration || :
      $1 ${2:-%{phpunit}} --no-coverage || ret=1
   fi
done
exit $ret
%else
: Test suite disabled
%endif


%files
%license LICENSE
%doc composer.json
%doc *.md
%{php_project}/*


%changelog
* Mon Apr 28 2025 Remi Collet <remi@remirepo.net> - 2.0.20-1
- update to 2.0.20 (no change)

* Fri Feb  7 2025 Remi Collet <remi@remirepo.net> - 2.0.19-1
- update to 2.0.19 (no change)

* Fri Dec 27 2024 Remi Collet <remi@remirepo.net> - 2.0.18-1
- update to 2.0.18
- raise dependency on PHP 8.1

* Mon Dec 23 2024 Remi Collet <remi@remirepo.net> - 2.0.17-1
- update to 2.0.17 (no change)
- re-license spec file to CECILL-2.1

* Mon Nov 25 2024 Remi Collet <remi@remirepo.net> - 2.0.16-1
- update to 2.0.16 (no change)

* Mon Oct 28 2024 Remi Collet <remi@remirepo.net> - 2.0.15-1
- update to 2.0.15 (no change)

* Mon Sep  9 2024 Remi Collet <remi@remirepo.net> - 2.0.14-1
- update to 2.0.14 (no change)

* Mon Aug 19 2024 Remi Collet <remi@remirepo.net> - 2.0.13-1
- update to 2.0.13 (no change)

* Fri Apr 12 2024 Remi Collet <remi@remirepo.net> - 2.0.11-1
- update to 2.0.11

* Wed Nov 29 2023 Remi Collet <remi@remirepo.net> - 2.0.10-1
- update to 2.0.10 (no change)

* Tue Nov 28 2023 Remi Collet <remi@remirepo.net> - 2.0.8-1
- update to 2.0.8 (no change)

* Wed Nov 22 2023 Remi Collet <remi@remirepo.net> - 2.0.7-1
- update to 2.0.7
- raise dependency on PHP 8
- raise dependency on tc-lib-unicode-data 2.0

* Mon Oct 23 2023 Remi Collet <remi@remirepo.net> - 1.4.33-1
- update to 1.4.33 (no change)

* Thu Oct 12 2023 Remi Collet <remi@remirepo.net> - 1.4.31-1
- update to 1.4.31

* Tue Oct 10 2023 Remi Collet <remi@remirepo.net> - 1.4.26-1
- update to 1.4.26

* Tue Oct 10 2023 Remi Collet <remi@remirepo.net> - 1.4.23-1
- update to 1.4.23

* Fri Sep  8 2023 Remi Collet <remi@remirepo.net> - 1.4.22-1
- update to 1.4.22

* Wed May 24 2023 Remi Collet <remi@remirepo.net> - 1.4.18-1
- update to 1.4.18 (no change)

* Fri May  5 2023 Remi Collet <remi@remirepo.net> - 1.4.17-1
- update to 1.4.17 (no change)

* Thu May  4 2023 Remi Collet <remi@remirepo.net> - 1.4.16-1
- update to 1.4.16 (no change)

* Wed May  3 2023 Remi Collet <remi@remirepo.net> - 1.4.14-1
- update to 1.4.14 (no change)

* Thu Dec 22 2022 Remi Collet <remi@remirepo.net> - 1.4.13-1
- update to 1.4.13 (no change)

* Tue Jun 14 2022 Remi Collet <remi@remirepo.net> - 1.4.9-1
- update to 1.4.9 (no change)

* Mon Jan  3 2022 Remi Collet <remi@remirepo.net> - 1.4.7-1
- update to 1.4.7 (no change)

* Mon Feb  8 2021 Remi Collet <remi@remirepo.net> - 1.4.4-1
- update to 1.4.4 (no change)

* Mon Dec 21 2020 Remi Collet <remi@remirepo.net> - 1.4.1-1
- update to 1.4.1
- switch to classmap autoloader

* Fri Jan  3 2020 Remi Collet <remi@remirepo.net> - 1.3.11-1
- update to 1.3.11 (no change)

* Fri Sep 20 2019 Remi Collet <remi@remirepo.net> - 1.3.9-1
- update to 1.3.9
- drop patch merged upstream

* Fri Sep 13 2019 Remi Collet <remi@remirepo.net> - 1.3.8-2
- add patch for 7.4 from
  https://github.com/tecnickcom/tc-lib-unicode/pull/5

* Mon Jun 25 2018 Remi Collet <remi@remirepo.net> - 1.3.8-1
- update to 1.3.8 (no change)

* Mon May 14 2018 Remi Collet <remi@remirepo.net> - 1.3.7-1
- update to 1.3.7 (no change)
- switch to phpunit7
- use range dependencies

* Tue Jan  2 2018 Remi Collet <remi@remirepo.net> - 1.3.6-1
- Update to 1.3.6

* Sun Feb 12 2017 Remi Collet <remi@remirepo.net> - 1.3.5-1
- update to 1.3.5 (no change)

* Mon Feb  6 2017 Remi Collet <remi@remirepo.net> - 1.3.4-1
- update to 1.3.4 (no change)

* Fri Sep  2 2016 Remi Collet <remi@fedoraproject.org> - 1.3.3-1
- update to 1.3.3 (no change)
- raise dependency on tecnickcom/tc-lib-unicode-data >= 1.6.3

* Tue Jun 14 2016 Remi Collet <remi@fedoraproject.org> - 1.3.0-1
- update to 1.3.0 (no change)

* Fri Mar  4 2016 Remi Collet <remi@fedoraproject.org> - 1.2.2-1
- update to 1.2.2 (no change)

* Fri Jan 15 2016 Remi Collet <remi@fedoraproject.org> - 1.2.1-1
- initial package, version 1.2.1

